@@ -1,9 +1,13 @@
 import os
-from loguru import logger
+
 import pymzml
-from tests.conftest import N_CHEMS, MIN_MS1_INTENSITY, get_rt_bounds, CENTRE_RANGE, run_environment, \
+from loguru import logger
+
+from tests.conftest import N_CHEMS, MIN_MS1_INTENSITY, get_rt_bounds, CENTRE_RANGE, \
+    run_environment, \
     check_non_empty_MS2, check_mzML, OUT_DIR, BEER_CHEMS, BEER_MIN_BOUND, BEER_MAX_BOUND, HMDB
-from vimms.ChemicalSamplers import EvenMZFormulaSampler, FixedMS2Sampler, UniformRTAndIntensitySampler, \
+from vimms.ChemicalSamplers import EvenMZFormulaSampler, FixedMS2Sampler, \
+    UniformRTAndIntensitySampler, \
     ConstantChromatogramSampler, DatabaseFormulaSampler
 from vimms.Chemicals import ChemicalMixtureCreator
 from vimms.Common import POSITIVE, set_log_level_warning, NEGATIVE, ScanParameters
@@ -16,7 +20,7 @@ from vimms.Noise import GaussianPeakNoise
 
 class TestNegative:
     def test_neg(self, even_chems):
-        mass_spec = IndependentMassSpectrometer(NEGATIVE, even_chems, None)
+        mass_spec = IndependentMassSpectrometer(NEGATIVE, even_chems)
         N = 10
         controller = TopNController(NEGATIVE, N, 0.7, 10, 15, 0, force_N=True)
         env = Environment(mass_spec, controller, 200, 300, progress_bar=True)
@@ -39,16 +43,16 @@ class TestNegative:
 
         run = pymzml.run.Reader(os.path.join(OUT_DIR, filename))
         for n, spec in enumerate(run):
-            assert spec.get('MS:1000129') # this is the negative scan accession
-
+            assert spec.get('MS:1000129')  # this is the negative scan accession
 
 
 class TestTopNForcedN:
     """
     Test the TopN controller when N is forced to be N. I.e. always fragment enough
     """
+
     def test_TopN_forceN(self, ten_chems):
-        mass_spec = IndependentMassSpectrometer(POSITIVE, ten_chems, None)
+        mass_spec = IndependentMassSpectrometer(POSITIVE, ten_chems)
         N = 20
         controller = TopNController(POSITIVE, N, 0.7, 10, 15, 0, force_N=True)
         env = Environment(mass_spec, controller, 200, 300, progress_bar=True)
@@ -56,24 +60,25 @@ class TestTopNForcedN:
 
         all_scans = controller.scans[1] + controller.scans[2]
         # sort by RT
-        all_scans.sort(key = lambda x: x.rt)
+        all_scans.sort(key=lambda x: x.rt)
         ms1_pos = []
         for i, s in enumerate(all_scans):
             if s.ms_level == 1:
                 ms1_pos.append(i)
-        
+
         for i, mp in enumerate(ms1_pos[:-1]):
-            assert ms1_pos[i+1] - (mp + 1) == N
+            assert ms1_pos[i + 1] - (mp + 1) == N
 
 
 class TestTopNController:
     """
-    Tests the Top-N controller that does standard DDA Top-N fragmentation scans with the simulated mass spec class.
+    Tests the Top-N controller that does standard DDA Top-N fragmentation scans with the
+    simulated mass spec class.
     """
 
-    def test_TopN_controller_with_simulated_chems(self, fragscan_dataset_peaks, fragscan_ps):
+    def test_TopN_controller_with_simulated_chems(self, fragscan_dataset):
         logger.info('Testing Top-N controller with simulated chemicals -- no noise')
-        assert len(fragscan_dataset_peaks) == N_CHEMS
+        assert len(fragscan_dataset) == N_CHEMS
 
         isolation_width = 1
         N = 10
@@ -82,9 +87,10 @@ class TestTopNController:
         ionisation_mode = POSITIVE
 
         # create a simulated mass spec without noise and Top-N controller
-        mass_spec = IndependentMassSpectrometer(ionisation_mode, fragscan_dataset_peaks, fragscan_ps)
-        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol, MIN_MS1_INTENSITY)
-        min_bound, max_bound = get_rt_bounds(fragscan_dataset_peaks, CENTRE_RANGE)
+        mass_spec = IndependentMassSpectrometer(ionisation_mode, fragscan_dataset)
+        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol,
+                                    MIN_MS1_INTENSITY)
+        min_bound, max_bound = get_rt_bounds(fragscan_dataset, CENTRE_RANGE)
 
         # create an environment to run both the mass spec and controller
         env = Environment(mass_spec, controller, min_bound, max_bound, progress_bar=True)
@@ -96,9 +102,9 @@ class TestTopNController:
         filename = 'topN_controller_simulated_chems_no_noise.mzML'
         check_mzML(env, OUT_DIR, filename)
 
-    def test_TopN_controller_with_simulated_chems_and_noise(self, fragscan_dataset_peaks, fragscan_ps):
+    def test_TopN_controller_with_simulated_chems_and_noise(self, fragscan_dataset):
         logger.info('Testing Top-N controller with simulated chemicals -- with noise')
-        assert len(fragscan_dataset_peaks) == N_CHEMS
+        assert len(fragscan_dataset) == N_CHEMS
 
         isolation_width = 1
         N = 10
@@ -109,10 +115,12 @@ class TestTopNController:
         # create a simulated mass spec with noise and Top-N controller
         mz_noise = GaussianPeakNoise(0.1)
         intensity_noise = GaussianPeakNoise(1000.)
-        mass_spec = IndependentMassSpectrometer(ionisation_mode, fragscan_dataset_peaks, fragscan_ps, mz_noise=mz_noise,
+        mass_spec = IndependentMassSpectrometer(ionisation_mode, fragscan_dataset,
+                                                mz_noise=mz_noise,
                                                 intensity_noise=intensity_noise)
-        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol, MIN_MS1_INTENSITY)
-        min_bound, max_bound = get_rt_bounds(fragscan_dataset_peaks, CENTRE_RANGE)
+        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol,
+                                    MIN_MS1_INTENSITY)
+        min_bound, max_bound = get_rt_bounds(fragscan_dataset, CENTRE_RANGE)
 
         # create an environment to run both the mass spec and controller
         env = Environment(mass_spec, controller, min_bound, max_bound, progress_bar=True)
@@ -125,7 +133,7 @@ class TestTopNController:
         filename = 'topN_controller_simulated_chems_with_noise.mzML'
         check_mzML(env, OUT_DIR, filename)
 
-    def test_TopN_controller_with_beer_chems(self, fragscan_ps):
+    def test_TopN_controller_with_beer_chems(self):
         logger.info('Testing Top-N controller with QC beer chemicals')
 
         isolation_width = 1
@@ -135,8 +143,9 @@ class TestTopNController:
         ionisation_mode = POSITIVE
 
         # create a simulated mass spec without noise and Top-N controller
-        mass_spec = IndependentMassSpectrometer(ionisation_mode, BEER_CHEMS, fragscan_ps)
-        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol, MIN_MS1_INTENSITY)
+        mass_spec = IndependentMassSpectrometer(ionisation_mode, BEER_CHEMS)
+        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol,
+                                    MIN_MS1_INTENSITY)
 
         # create an environment to run both the mass spec and controller
         env = Environment(mass_spec, controller, BEER_MIN_BOUND, BEER_MAX_BOUND, progress_bar=True)
@@ -149,8 +158,9 @@ class TestTopNController:
         filename = 'topN_controller_qcbeer_chems_no_noise.mzML'
         check_mzML(env, OUT_DIR, filename)
 
-    def test_TopN_controller_with_beer_chems_and_scan_duration_dict(self, fragscan_ps):
-        logger.info('Testing Top-N controller with QC beer chemicals passing in the scan durations')
+    def test_TopN_controller_with_beer_chems_and_scan_duration_dict(self):
+        logger.info('Testing Top-N controller with QC beer chemicals '
+                    'passing in the scan durations')
 
         isolation_width = 1
         N = 10
@@ -158,12 +168,15 @@ class TestTopNController:
         mz_tol = 10
         ionisation_mode = POSITIVE
 
-        ps = None
+        # ps = None
         scan_duration_dict = {1: 0.2, 2: 0.1}
 
-        # create a simulated mass spec without noise and Top-N controller and passing in the scan_duration dict
-        mass_spec = IndependentMassSpectrometer(ionisation_mode, BEER_CHEMS, ps, scan_duration_dict=scan_duration_dict)
-        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol, MIN_MS1_INTENSITY)
+        # create a simulated mass spec without noise and Top-N controller and passing
+        # in the scan_duration dict
+        mass_spec = IndependentMassSpectrometer(ionisation_mode, BEER_CHEMS,
+                                                scan_duration=scan_duration_dict)
+        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol,
+                                    MIN_MS1_INTENSITY)
 
         # create an environment to run both the mass spec and controller
         env = Environment(mass_spec, controller, BEER_MIN_BOUND, BEER_MAX_BOUND, progress_bar=True)
@@ -176,31 +189,9 @@ class TestTopNController:
         filename = 'topN_controller_qcbeer_chems_no_noise_with_scan_duration.mzML'
         check_mzML(env, OUT_DIR, filename)
 
-    def test_TopN_controller_with_simulated_chems_onlyMH(self, fragscan_dataset_peaks_onlyMH, fragscan_ps):
-        logger.info('Testing Top-N controller with simulated chemicals -- no noise, only MH adducts')
-        assert len(fragscan_dataset_peaks_onlyMH) == N_CHEMS
-
-        isolation_width = 1
-        N = 10
-        rt_tol = 15
-        mz_tol = 10
-        ionisation_mode = POSITIVE
-
-        # create a simulated mass spec without noise and Top-N controller
-        mass_spec = IndependentMassSpectrometer(ionisation_mode, fragscan_dataset_peaks_onlyMH, fragscan_ps)
-        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol, MIN_MS1_INTENSITY)
-        min_bound, max_bound = get_rt_bounds(fragscan_dataset_peaks_onlyMH, CENTRE_RANGE)
-
-        # create an environment to run both the mass spec and controller
-        env = Environment(mass_spec, controller, min_bound, max_bound, progress_bar=True)
-        run_environment(env)
-
-        # write simulated output to mzML file
-        filename = 'topN_controller_simulated_chems_no_noise_onlyMH.mzML'
-        check_mzML(env, OUT_DIR, filename)
 
 class TestTopNAdvanced:
-    def test_TopN_controller_advanced_params(self, fragscan_dataset_peaks_onlyMH, fragscan_ps):
+    def test_TopN_controller_advanced_params(self):
         # set some values that are not the defaults, so we know they're passed correctly
         params = AdvancedParams(
             default_ms1_scan_window=(10.0, 2000.0),
@@ -229,8 +220,9 @@ class TestTopNAdvanced:
         ionisation_mode = POSITIVE
 
         # create a simulated mass spec without noise and Top-N controller
-        mass_spec = IndependentMassSpectrometer(ionisation_mode, BEER_CHEMS, fragscan_ps)
-        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol, MIN_MS1_INTENSITY, params=params)
+        mass_spec = IndependentMassSpectrometer(ionisation_mode, BEER_CHEMS)
+        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol,
+                                    MIN_MS1_INTENSITY, advanced_params=params)
 
         # create an environment to run both the mass spec and controller
         env = Environment(mass_spec, controller, BEER_MIN_BOUND, BEER_MAX_BOUND, progress_bar=True)
@@ -245,7 +237,7 @@ class TestTopNAdvanced:
         assert scan_params.get(ScanParameters.AGC_TARGET) == params.ms1_agc_target
         assert scan_params.get(ScanParameters.MAX_IT) == params.ms1_max_it
         assert scan_params.get(ScanParameters.COLLISION_ENERGY) == params.ms1_collision_energy
-        assert scan_params.get(ScanParameters.ORBITRAP_RESOLUTION) == params.ms1_orbitrap_resolution
+        assert scan_params.get(ScanParameters.ORBITRAP_RESOLUTION) == params.ms1_orbitrap_resolution # noqa
         assert scan_params.get(ScanParameters.ACTIVATION_TYPE) == params.ms1_activation_type
         assert scan_params.get(ScanParameters.MASS_ANALYSER) == params.ms1_mass_analyser
         assert scan_params.get(ScanParameters.ISOLATION_MODE) == params.ms1_isolation_mode
@@ -257,23 +249,22 @@ class TestTopNAdvanced:
         assert scan_params.get(ScanParameters.AGC_TARGET) == params.ms2_agc_target
         assert scan_params.get(ScanParameters.MAX_IT) == params.ms2_max_it
         assert scan_params.get(ScanParameters.COLLISION_ENERGY) == params.ms2_collision_energy
-        assert scan_params.get(ScanParameters.ORBITRAP_RESOLUTION) == params.ms2_orbitrap_resolution
+        assert scan_params.get(ScanParameters.ORBITRAP_RESOLUTION) == params.ms2_orbitrap_resolution # noqa
         assert scan_params.get(ScanParameters.ACTIVATION_TYPE) == params.ms2_activation_type
         assert scan_params.get(ScanParameters.MASS_ANALYSER) == params.ms2_mass_analyser
         assert scan_params.get(ScanParameters.ISOLATION_MODE) == params.ms2_isolation_mode
         assert scan_params.get(ScanParameters.SOURCE_CID_ENERGY) == params.ms2_source_cid_energy
 
 
-
 class TestTopNControllerSpectra:
     """
-    Tests the Top-N controller that does standard DDA Top-N fragmentation scans with the simulated mass spec class.
-    Fragment spectra are generated via the "spectra" method
+    Tests the Top-N controller that does standard DDA Top-N fragmentation scans with the
+    simulated mass spec class. Fragment spectra are generated via the "spectra" method
     """
 
-    def test_TopN_controller_with_simulated_chems(self, fragscan_dataset_spectra, fragscan_ps):
+    def test_TopN_controller_with_simulated_chems(self, fragscan_dataset):
         logger.info('Testing Top-N controller with simulated chemicals -- no noise')
-        assert len(fragscan_dataset_spectra) == N_CHEMS
+        assert len(fragscan_dataset) == N_CHEMS
 
         isolation_width = 1
         N = 10
@@ -282,9 +273,10 @@ class TestTopNControllerSpectra:
         ionisation_mode = POSITIVE
 
         # create a simulated mass spec without noise and Top-N controller
-        mass_spec = IndependentMassSpectrometer(ionisation_mode, fragscan_dataset_spectra, fragscan_ps)
-        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol, MIN_MS1_INTENSITY)
-        min_bound, max_bound = get_rt_bounds(fragscan_dataset_spectra, CENTRE_RANGE)
+        mass_spec = IndependentMassSpectrometer(ionisation_mode, fragscan_dataset)
+        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol,
+                                    MIN_MS1_INTENSITY)
+        min_bound, max_bound = get_rt_bounds(fragscan_dataset, CENTRE_RANGE)
 
         # create an environment to run both the mass spec and controller
         env = Environment(mass_spec, controller, min_bound, max_bound, progress_bar=True)
@@ -303,7 +295,8 @@ class TestIonisationMode:
         ms = FixedMS2Sampler()
         ri = UniformRTAndIntensitySampler(min_rt=100, max_rt=101)
         cs = ConstantChromatogramSampler()
-        cm = ChemicalMixtureCreator(fs, ms2_sampler=ms, rt_and_intensity_sampler=ri, chromatogram_sampler=cs)
+        cm = ChemicalMixtureCreator(fs, ms2_sampler=ms, rt_and_intensity_sampler=ri,
+                                    chromatogram_sampler=cs)
         dataset = cm.sample(3, 2)
 
         N = 10
@@ -311,8 +304,9 @@ class TestIonisationMode:
         mz_tol = 10
         rt_tol = 15
 
-        ms = IndependentMassSpectrometer(POSITIVE, dataset, None)
-        controller = TopNController(POSITIVE, N, isolation_width, mz_tol, rt_tol, MIN_MS1_INTENSITY)
+        ms = IndependentMassSpectrometer(POSITIVE, dataset)
+        controller = TopNController(POSITIVE, N, isolation_width, mz_tol, rt_tol,
+                                    MIN_MS1_INTENSITY)
         env = Environment(ms, controller, 102, 110, progress_bar=True)
         set_log_level_warning()
         env.run()
@@ -332,7 +326,8 @@ class TestIonisationMode:
         ms = FixedMS2Sampler()
         ri = UniformRTAndIntensitySampler(min_rt=100, max_rt=101)
         cs = ConstantChromatogramSampler()
-        cm = ChemicalMixtureCreator(fs, ms2_sampler=ms, rt_and_intensity_sampler=ri, chromatogram_sampler=cs)
+        cm = ChemicalMixtureCreator(fs, ms2_sampler=ms, rt_and_intensity_sampler=ri,
+                                    chromatogram_sampler=cs)
         dataset = cm.sample(3, 2)
 
         N = 10
@@ -340,8 +335,9 @@ class TestIonisationMode:
         mz_tol = 10
         rt_tol = 15
 
-        ms = IndependentMassSpectrometer(NEGATIVE, dataset, None)
-        controller = TopNController(NEGATIVE, N, isolation_width, mz_tol, rt_tol, MIN_MS1_INTENSITY)
+        ms = IndependentMassSpectrometer(NEGATIVE, dataset)
+        controller = TopNController(NEGATIVE, N, isolation_width, mz_tol, rt_tol,
+                                    MIN_MS1_INTENSITY)
         env = Environment(ms, controller, 102, 110, progress_bar=True)
         set_log_level_warning()
         env.run()
@@ -362,7 +358,8 @@ class TestIonisationMode:
         cs = ConstantChromatogramSampler()
         adduct_prior_dict = {POSITIVE: {'M+H': 100, 'M+Na': 100, 'M+K': 100}}
         cm = ChemicalMixtureCreator(fs, rt_and_intensity_sampler=ri, chromatogram_sampler=cs,
-                                    adduct_prior_dict=adduct_prior_dict, adduct_proportion_cutoff=0.0)
+                                    adduct_prior_dict=adduct_prior_dict,
+                                    adduct_proportion_cutoff=0.0)
 
         n_adducts = len(adduct_prior_dict[POSITIVE])
         n_chems = 5
@@ -374,7 +371,7 @@ class TestIonisationMode:
         # should be 15 peaks or less all the time
         # some adducts might not be sampled if the probability is less than 0.2
         controller = SimpleMs1Controller()
-        ms = IndependentMassSpectrometer(POSITIVE, dataset, None)
+        ms = IndependentMassSpectrometer(POSITIVE, dataset)
         env = Environment(ms, controller, 102, 110, progress_bar=True)
         set_log_level_warning()
         env.run()
@@ -383,8 +380,9 @@ class TestIonisationMode:
 
 
 class TestExclusion:
-    def test_TopN_controller_with_beer_chems_and_initial_exclusion_list(self, fragscan_ps):
-        logger.info('Testing Top-N controller with QC beer chemicals and an initial exclusion list')
+    def test_TopN_controller_with_beer_chems_and_initial_exclusion_list(self):
+        logger.info('Testing Top-N controller with QC beer chemicals and '
+                    'an initial exclusion list')
 
         isolation_width = 1
         N = 10
@@ -394,14 +392,21 @@ class TestExclusion:
 
         initial_exclusion_list = []
         for i in range(3):
-            mass_spec = IndependentMassSpectrometer(ionisation_mode, BEER_CHEMS, fragscan_ps)
-            controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol, MIN_MS1_INTENSITY,
+            mass_spec = IndependentMassSpectrometer(ionisation_mode, BEER_CHEMS)
+            controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol,
+                                        MIN_MS1_INTENSITY,
                                         initial_exclusion_list=initial_exclusion_list)
-            print('exclude = %d' % len(controller.exclusion.exclusion_list))
-            env = Environment(mass_spec, controller, BEER_MIN_BOUND, BEER_MAX_BOUND, progress_bar=True)
+            env = Environment(mass_spec, controller, BEER_MIN_BOUND, BEER_MAX_BOUND,
+                              progress_bar=True)
             run_environment(env)
 
-            initial_exclusion_list = controller.exclusion.exclusion_list
+            mz_intervals = list(controller.exclusion.exclusion_list.boxes_mz.items())
+            rt_intervals = list(controller.exclusion.exclusion_list.boxes_rt.items())
+            unique_items_mz = set(i.data for i in mz_intervals)
+            unique_items_rt = set(i.data for i in rt_intervals)
+            assert len(unique_items_mz) == len(unique_items_rt)
+
+            initial_exclusion_list = list(unique_items_mz)
 
             # check that there is at least one non-empty MS2 scan
             check_non_empty_MS2(controller)
@@ -429,14 +434,21 @@ class TestExclusion:
         isolation_width = 1
         all_controllers = []
         for i in range(3):
-            mass_spec = IndependentMassSpectrometer(ionisation_mode, dataset, None)
-            controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol, min_ms1_intensity,
+            mass_spec = IndependentMassSpectrometer(ionisation_mode, dataset)
+            controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol,
+                                        min_ms1_intensity,
                                         initial_exclusion_list=initial_exclusion_list)
-            print('exclude = %d' % len(controller.exclusion.exclusion_list))
             env = Environment(mass_spec, controller, 0, 20, progress_bar=True)
             run_environment(env)
 
-            initial_exclusion_list = controller.exclusion.exclusion_list
+            mz_intervals = list(controller.exclusion.exclusion_list.boxes_mz.items())
+            rt_intervals = list(controller.exclusion.exclusion_list.boxes_rt.items())
+            unique_items_mz = set(i.data for i in mz_intervals)
+            unique_items_rt = set(i.data for i in rt_intervals)
+            assert len(unique_items_mz) == len(unique_items_rt)
+
+            initial_exclusion_list = list(unique_items_mz)
+
             all_controllers.append(controller)
         assert len(all_controllers[0].scans[2]) == n_chems
         assert len(all_controllers[1].scans[2]) == 0
@@ -445,10 +457,11 @@ class TestExclusion:
 
 class TestTopNShiftedController:
     """
-    Tests the Top-N controller that does standard DDA Top-N fragmentation scans with the beer chems.
+    Tests the Top-N controller that does standard DDA Top-N fragmentation scans with
+    the beer chems.
     """
 
-    def test_TopN_controller_with_beer_chems(self, fragscan_ps):
+    def test_TopN_controller_with_beer_chems(self):
         logger.info('Testing Top-N controller with QC beer chemicals')
         test_shift = 0
         isolation_width = 1
@@ -460,13 +473,14 @@ class TestTopNShiftedController:
         scan_duration_dict = {1: 0.2, 2: 0.1}
 
         # create a simulated mass spec without noise and Top-N controller
-        mass_spec = IndependentMassSpectrometer(ionisation_mode, BEER_CHEMS, fragscan_ps,
-                                                scan_duration_dict=scan_duration_dict)
-        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol, MIN_MS1_INTENSITY,
-                                    ms1_shift=test_shift)
+        mass_spec = IndependentMassSpectrometer(ionisation_mode, BEER_CHEMS,
+                                                scan_duration=scan_duration_dict)
+        controller = TopNController(ionisation_mode, N, isolation_width, mz_tol, rt_tol,
+                                    MIN_MS1_INTENSITY, ms1_shift=test_shift)
 
         # create an environment to run both the mass spec and controller
-        env = Environment(mass_spec, controller, BEER_MIN_BOUND, BEER_MAX_BOUND, progress_bar=True)
+        env = Environment(mass_spec, controller, BEER_MIN_BOUND, BEER_MAX_BOUND,
+                          progress_bar=True)
         run_environment(env)
 
         # check that there is at least one non-empty MS2 scan
@@ -479,10 +493,11 @@ class TestTopNShiftedController:
 
 class TestWeightedDEWController:
     """
-    Tests the Top-N controller that does standard DDA Top-N fragmentation scans with the beer chems.
+    Tests the Top-N controller that does standard DDA Top-N fragmentation scans
+    with the beer chems.
     """
 
-    def test_WeightedDEW_controller_with_beer_chems(self, fragscan_ps):
+    def test_WeightedDEW_controller_with_beer_chems(self):
         logger.info('Testing excluding Top-N controller with QC beer chemicals')
         test_shift = 0
         isolation_width = 1
@@ -494,15 +509,15 @@ class TestWeightedDEWController:
         scan_duration_dict = {1: 0.2, 2: 0.1}
 
         # create a simulated mass spec without noise and Top-N controller
-        mass_spec = IndependentMassSpectrometer(ionisation_mode, BEER_CHEMS, fragscan_ps,
-                                                scan_duration_dict=scan_duration_dict)
-        controller = WeightedDEWController(ionisation_mode, N, isolation_width, mz_tol, rt_tol, MIN_MS1_INTENSITY,
-                                           ms1_shift=test_shift,
-                                           exclusion_t_0=exclusion_t_0,
-                                           log_intensity=True)
+        mass_spec = IndependentMassSpectrometer(ionisation_mode, BEER_CHEMS,
+                                                scan_duration=scan_duration_dict)
+        controller = WeightedDEWController(ionisation_mode, N, isolation_width, mz_tol, rt_tol,
+                                           MIN_MS1_INTENSITY, ms1_shift=test_shift,
+                                           exclusion_t_0=exclusion_t_0, log_intensity=True)
 
         # create an environment to run both the mass spec and controller
-        env = Environment(mass_spec, controller, BEER_MIN_BOUND, BEER_MAX_BOUND, progress_bar=True)
+        env = Environment(mass_spec, controller, BEER_MIN_BOUND, BEER_MAX_BOUND,
+                          progress_bar=True)
         run_environment(env)
 
         # check that there is at least one non-empty MS2 scan
@@ -510,4 +525,4 @@ class TestWeightedDEWController:
 
         # write simulated output to mzML file
         filename = 'topN_weighted_dew_controller_qcbeer_chems_no_noise.mzML'
-        check_mzML(env, OUT_DIR, filename)
\ No newline at end of file
+        check_mzML(env, OUT_DIR, filename)
