@@ -15,6 +15,7 @@ import requests
 from loguru import logger
 from tqdm.auto import tqdm
 
+from mass_spec_utils.data_import.mzml import MZMLFile
 ###############################################################################
 # Common constants
 ###############################################################################
@@ -118,11 +119,6 @@ ROI_EXCLUSION_DEW = 'exclusion_dew'
 ROI_EXCLUSION_WEIGHTED_DEW = 'exclusion_weighted_dew'
 
 GRID_CONTROLLER_SCORING_PARAMS = {
-    'theta1': 1,
-    'dda_weight': 1,
-    'overlap_weight': 1,
-    'smartroi_weight': 1,
-    'smartroi_score_add': True,
     'theta1': 1,
     'theta2': 0,
     'theta3': 0,
@@ -380,7 +376,14 @@ def create_if_not_exist(out_dir):
     if not pathlib.Path(out_dir).exists():
         logger.info('Created %s' % out_dir)
         pathlib.Path(out_dir).mkdir(parents=True, exist_ok=True)
-
+        
+def path_or_mzml(mzml):    
+    try:
+        mzml = MZMLFile(mzml)
+    except:
+        if(not type(mzml) == MZMLFile):
+            raise NotImplementedError("Didn't recognise the MZMLFile!")
+    return mzml
 
 def save_obj(obj, filename):
     """
